pub struct ExceptionTableEntry {
pub covered_pc: Range<ProgramCounter>,
pub handler_pc: ProgramCounter,
pub catch_type: Option<ClassRef>,
}Expand description
An entry in the exception table.
Fields
covered_pc: Range<ProgramCounter>The half-open range of locations where the exception handler is active.
This corresponds to the JVM class file’s start_pc <= pc < end_pc invariant.
handler_pc: ProgramCounterThe location of the exception handler.
catch_type: Option<ClassRef>The type of the exception to be handled.
Implementations
Sourceimpl ExceptionTableEntry
impl ExceptionTableEntry
Sourcepub fn covers(&self, pc: ProgramCounter) -> bool
pub fn covers(&self, pc: ProgramCounter) -> bool
Checks whether the given program counter is covered by this exception handler.