pub struct Module {
pub name: String,
pub flags: Flags,
pub version: Option<String>,
pub requires: Vec<Require>,
pub exports: Vec<Export>,
pub opens: Vec<Open>,
pub uses: Vec<ClassRef>,
pub provides: Vec<Provide>,
}Expand description
A module in the Java Platform Module System (JPMS). See the JVM Specification 4.7.25 for more information.
Fields
name: StringThe name of the module.
flags: FlagsThe flags of the module.
version: Option<String>The version of the module.
requires: Vec<Require>A list of the modules that are required by this module.
exports: Vec<Export>A list of the modules that are exported by this module.
opens: Vec<Open>A list of the modules that are opened by this module.
uses: Vec<ClassRef>A list of the classes that are used by this module.
provides: Vec<Provide>A list of the services that are provided by this module.