pub enum Expression {
Const(ConstantValue),
Call {
method: MethodRef,
this: Option<Operand>,
args: Vec<Operand>,
},
Closure {
name: String,
captures: Vec<Operand>,
bootstrap_method_index: u16,
closure_descriptor: MethodDescriptor,
},
Math(MathOperation),
Field(FieldAccess),
Array(ArrayOperation),
Conversion(Conversion),
Throw(Operand),
Synchronization(LockOperation),
New(ClassRef),
Subroutine {
return_address: ProgramCounter,
target: ProgramCounter,
},
}Available on crate feature
unstable-moka-ir only.Expand description
Represents an expression in the Moka IR. It may or may not generate a value.
Variants
Const(ConstantValue)
A constant value.
Call
A function call Corresponds to the following JVM instructions:
invokestaticinvokevirtualinvokespecialinvokeinterface
Closure
A call to a bootstrap method to create a closure. Corresponds to the following JVM instructions:
invokedynamic
Fields

closure_descriptor: MethodDescriptorThe descriptor of the closure generation.
Math(MathOperation)
A mathematical operation.
Field(FieldAccess)
A field access.
Array(ArrayOperation)
An array operation.
Conversion(Conversion)
A type conversion.
Throw(Operand)
Throws an exception.
Synchronization(LockOperation)
An operation on a monitor.
New(ClassRef)
Creates a new object.
Subroutine
A return address.
Fields

return_address: ProgramCounterThe address to return to.

target: ProgramCounterThe address where the subroutine starts.
Implementations
Sourceimpl Expression
impl Expression
Sourcepub fn uses(&self) -> HashSet<Identifier>
pub fn uses(&self) -> HashSet<Identifier>
Returns the set of Identifiers used by the expression.